==> esp32s3-0.1.0.crate: esp32s3-0.1.0/src/wcl/core_0_world_dram0_pif.rs <==
#[doc = "Register `Core_0_World_DRam0_PIF` reader"]
pub struct R(crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `Core_0_World_DRam0_PIF` writer"]
pub struct W(crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CORE_0_WORLD_DRAM0_PIF` reader - this field is used to read current world of Dram0 bus and PIF bus"]
pub struct CORE_0_WORLD_DRAM0_PIF_R(crate::FieldReader<u8, u8>);
impl CORE_0_WORLD_DRAM0_PIF_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        CORE_0_WORLD_DRAM0_PIF_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CORE_0_WORLD_DRAM0_PIF_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CORE_0_WORLD_DRAM0_PIF` writer - this field is used to read current world of Dram0 bus and PIF bus"]
pub struct CORE_0_WORLD_DRAM0_PIF_W<'a> {
    w: &'a mut W,
}
impl<'a> CORE_0_WORLD_DRAM0_PIF_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:1 - this field is used to read current world of Dram0 bus and PIF bus"]
    #[inline(always)]
    pub fn core_0_world_dram0_pif(&self) -> CORE_0_WORLD_DRAM0_PIF_R {
        CORE_0_WORLD_DRAM0_PIF_R::new((self.bits & 0x03) as u8)
    }
}
impl W {
    #[doc = "Bits 0:1 - this field is used to read current world of Dram0 bus and PIF bus"]
    #[inline(always)]
    pub fn core_0_world_dram0_pif(&mut self) -> CORE_0_WORLD_DRAM0_PIF_W {
        CORE_0_WORLD_DRAM0_PIF_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Core_0 dram0 and PIF world register\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [core_0_world_dram0_pif]
(index.html) module"]
pub struct CORE_0_WORLD_DRAM0_PIF_SPEC;
impl crate::RegisterSpec for CORE_0_WORLD_DRAM0_PIF_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [core_0_world_dram0_pif::R]
(R) reader structure"]
impl crate::Readable for CORE_0_WORLD_DRAM0_PIF_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [core_0_world_dram0_pif::W]
(W) writer structure"]
impl crate::Writable for CORE_0_WORLD_DRAM0_PIF_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets Core_0_World_DRam0_PIF to value 0"]
impl crate::Resettable for CORE_0_WORLD_DRAM0_PIF_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32s3-0.2.0.crate: esp32s3-0.2.0/src/wcl/core_0_world_dram0_pif.rs <==
#[doc = "Register `Core_0_World_DRam0_PIF` reader"]
pub struct R(crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CORE_0_WORLD_DRAM0_PIF_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `Core_0_World_DRam0_PIF` writer"]
pub struct W(crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CORE_0_WORLD_DRAM0_PIF_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CORE_0_WORLD_DRAM0_PIF` reader - this field is used to read current world of Dram0 bus and PIF bus"]
pub struct CORE_0_WORLD_DRAM0_PIF_R(crate::FieldReader<u8, u8>);
impl CORE_0_WORLD_DRAM0_PIF_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        CORE_0_WORLD_DRAM0_PIF_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CORE_0_WORLD_DRAM0_PIF_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CORE_0_WORLD_DRAM0_PIF` writer - this field is used to read current world of Dram0 bus and PIF bus"]
pub struct CORE_0_WORLD_DRAM0_PIF_W<'a> {
    w: &'a mut W,
}
impl<'a> CORE_0_WORLD_DRAM0_PIF_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:1 - this field is used to read current world of Dram0 bus and PIF bus"]
    #[inline(always)]
    pub fn core_0_world_dram0_pif(&self) -> CORE_0_WORLD_DRAM0_PIF_R {
        CORE_0_WORLD_DRAM0_PIF_R::new((self.bits & 3) as u8)
    }
}
impl W {
    #[doc = "Bits 0:1 - this field is used to read current world of Dram0 bus and PIF bus"]
    #[inline(always)]
    pub fn core_0_world_dram0_pif(&mut self) -> CORE_0_WORLD_DRAM0_PIF_W {
        CORE_0_WORLD_DRAM0_PIF_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Core_0 dram0 and PIF world register\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [core_0_world_dram0_pif]
(index.html) module"]
pub struct CORE_0_WORLD_DRAM0_PIF_SPEC;
impl crate::RegisterSpec for CORE_0_WORLD_DRAM0_PIF_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [core_0_world_dram0_pif::R]
(R) reader structure"]
impl crate::Readable for CORE_0_WORLD_DRAM0_PIF_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [core_0_world_dram0_pif::W]
(W) writer structure"]
impl crate::Writable for CORE_0_WORLD_DRAM0_PIF_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets Core_0_World_DRam0_PIF to value 0"]
impl crate::Resettable for CORE_0_WORLD_DRAM0_PIF_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
